@@ -1,8 +1,9 @@
 package XML::Directory::Apache;
 
-require 5.005_62;
+require 5.005_03;
+BEGIN { require warnings if $] >= 5.006; }
+
 use strict;
-use warnings;
 use XML::Directory::String;
 use Apache::Constants qw(:common );
 
