@@ -3,7 +3,7 @@
 use XML::Directory::String;
 use strict;
 
-(@ARGV == 1 ) || die ("Usage: dir2xml_oo.pl path\n\n");
+(@ARGV == 1 ) || die ("Usage: dir2xml_string.pl path\n\n");
 
 my $path = shift;
 
